@@ -33,9 +33,9 @@
 
 // KDE includes.
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdialog.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kurllabel.h>
 
 // Local includes.
@@ -538,109 +538,109 @@ void DcrawSettingsWidget::setup(int advSettings)
 
     // ---------------------------------------------------------------
 
-    connect(d->unclipColorComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotUnclipColorActivated(int)));
+    connect(d->unclipColorComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotUnclipColorActivated(int)));
 
-    connect(d->whiteBalanceComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotWhiteBalanceToggled(int)));
+    connect(d->whiteBalanceComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotWhiteBalanceToggled(int)));
 
-    connect(d->enableNoiseReduction, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotNoiseReductionToggled(bool)));
+    connect(d->enableNoiseReduction, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotNoiseReductionToggled(bool)));
 
-    connect(d->enableCACorrection, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotCACorrectionToggled(bool)));
+    connect(d->enableCACorrection, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotCACorrectionToggled(bool)));
 
-    connect(d->blackPointCheckBox, TQT_SIGNAL(toggled(bool)),
-            d->blackPointSpinBox, TQT_SLOT(setEnabled(bool)));
+    connect(d->blackPointCheckBox, TQ_SIGNAL(toggled(bool)),
+            d->blackPointSpinBox, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->whitePointCheckBox, TQT_SIGNAL(toggled(bool)),
-            d->whitePointSpinBox, TQT_SLOT(setEnabled(bool)));
+    connect(d->whitePointCheckBox, TQ_SIGNAL(toggled(bool)),
+            d->whitePointSpinBox, TQ_SLOT(setEnabled(bool)));
 
-    connect(d->sixteenBitsImage, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SLOT(slotsixteenBitsImageToggled(bool)));
+    connect(d->sixteenBitsImage, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SLOT(slotsixteenBitsImageToggled(bool)));
 
-    connect(dcrawVersion, TQT_SIGNAL(leftClickedURL(const TQString&)),
-            this, TQT_SLOT(processDcrawURL(const TQString&)));
+    connect(dcrawVersion, TQ_SIGNAL(leftClickedURL(const TQString&)),
+            this, TQ_SLOT(processDcrawURL(const TQString&)));
 
-    connect(d->inputColorSpaceComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotInputColorSpaceChanged(int)));
+    connect(d->inputColorSpaceComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotInputColorSpaceChanged(int)));
 
-    connect(d->outputColorSpaceComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotOutputColorSpaceChanged(int)));
+    connect(d->outputColorSpaceComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotOutputColorSpaceChanged(int)));
 
     // Wrapper to emit signal when something is changed in settings.
 
-    connect(d->inIccUrlEdit, TQT_SIGNAL(urlSelected(const TQString&)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->inIccUrlEdit, TQ_SIGNAL(urlSelected(const TQString&)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->outIccUrlEdit, TQT_SIGNAL(urlSelected(const TQString&)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->outIccUrlEdit, TQ_SIGNAL(urlSelected(const TQString&)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->whiteBalanceComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->whiteBalanceComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->RAWQualityComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->RAWQualityComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->unclipColorComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->unclipColorComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->inputColorSpaceComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->inputColorSpaceComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->outputColorSpaceComboBox, TQT_SIGNAL(activated(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->outputColorSpaceComboBox, TQ_SIGNAL(activated(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->blackPointCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->blackPointCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->whitePointCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->whitePointCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->sixteenBitsImage, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->sixteenBitsImage, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->fourColorCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->fourColorCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->dontStretchPixelsCheckBox, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->dontStretchPixelsCheckBox, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->enableNoiseReduction, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->enableNoiseReduction, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->enableCACorrection, TQT_SIGNAL(toggled(bool)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->enableCACorrection, TQ_SIGNAL(toggled(bool)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->customWhiteBalanceSpinBox, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->customWhiteBalanceSpinBox, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->reconstructSpinBox, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->reconstructSpinBox, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->blackPointSpinBox, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->blackPointSpinBox, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->whitePointSpinBox, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->whitePointSpinBox, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->NRThresholdSpinBox, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->NRThresholdSpinBox, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->medianFilterPassesSpinBox, TQT_SIGNAL(valueChanged(int)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->medianFilterPassesSpinBox, TQ_SIGNAL(valueChanged(int)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->customWhiteBalanceGreenSpinBox, TQT_SIGNAL(valueChanged(double)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->customWhiteBalanceGreenSpinBox, TQ_SIGNAL(valueChanged(double)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->caRedMultSpinBox, TQT_SIGNAL(valueChanged(double)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->caRedMultSpinBox, TQ_SIGNAL(valueChanged(double)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->caBlueMultSpinBox, TQT_SIGNAL(valueChanged(double)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->caBlueMultSpinBox, TQ_SIGNAL(valueChanged(double)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 
-    connect(d->brightnessSpinBox, TQT_SIGNAL(valueChanged(double)),
-            this, TQT_SIGNAL(signalSettingsChanged()));
+    connect(d->brightnessSpinBox, TQ_SIGNAL(valueChanged(double)),
+            this, TQ_SIGNAL(signalSettingsChanged()));
 }
 
 DcrawSettingsWidget::~DcrawSettingsWidget()
@@ -660,7 +660,7 @@ void DcrawSettingsWidget::updateMinimumWidth()
 
 void DcrawSettingsWidget::processDcrawURL(const TQString& url)
 {
-    KApplication::kApplication()->invokeBrowser(url);
+    TDEApplication::kApplication()->invokeBrowser(url);
 }
 
 KURLRequester* DcrawSettingsWidget::inputProfileUrlEdit() const
